diff --git a/MP.MONO.SIM/MP.MONO.SIM.csproj b/MP.MONO.SIM/MP.MONO.SIM.csproj
index 086c9ea..2959f7a 100644
--- a/MP.MONO.SIM/MP.MONO.SIM.csproj
+++ b/MP.MONO.SIM/MP.MONO.SIM.csproj
@@ -6,7 +6,7 @@
enable
enable
AnyCPU;x86;x64
- 1.2.2210.318
+ 1.2.2210.412
diff --git a/MP.MONO.SIM/Resources/ChangeLog.html b/MP.MONO.SIM/Resources/ChangeLog.html
index 77564fa..20f2999 100644
--- a/MP.MONO.SIM/Resources/ChangeLog.html
+++ b/MP.MONO.SIM/Resources/ChangeLog.html
@@ -1,6 +1,6 @@
MAPO-MONO
- Version: 1.2.2210.318
+ Version: 1.2.2210.412
Release Note:
-
diff --git a/MP.MONO.SIM/Resources/VersNum.txt b/MP.MONO.SIM/Resources/VersNum.txt
index 2317054..d7d71d8 100644
--- a/MP.MONO.SIM/Resources/VersNum.txt
+++ b/MP.MONO.SIM/Resources/VersNum.txt
@@ -1 +1 @@
-1.2.2210.318
+1.2.2210.412
diff --git a/MP.MONO.SIM/Resources/manifest.xml b/MP.MONO.SIM/Resources/manifest.xml
index 2d4930b..e20a997 100644
--- a/MP.MONO.SIM/Resources/manifest.xml
+++ b/MP.MONO.SIM/Resources/manifest.xml
@@ -1,6 +1,6 @@
-
- 1.2.2210.318
+ 1.2.2210.412
http://nexus.steamware.net/repository/SWS/MP.MONO.SIM/stable/LAST/MP.Mon.zip
http://nexus.steamware.net/repository/SWS/MP.MONO.SIM/stable/LAST/ChangeLog.html
false
diff --git a/MP.MONO.SIM/conf/SimTools.json b/MP.MONO.SIM/conf/SimTools.json
index 6d408af..c8425ee 100644
--- a/MP.MONO.SIM/conf/SimTools.json
+++ b/MP.MONO.SIM/conf/SimTools.json
@@ -8,7 +8,7 @@
"ValueNum": 99,
"MinVal": 0,
"MaxVal": 100,
- "SimMean": -0.05,
+ "SimMean": -0.5,
"SimStd": 0.125,
"DisplFormat": "N2",
"IsNumeric": true,
@@ -24,7 +24,7 @@
"ValueNum": 85,
"MinVal": 0,
"MaxVal": 100,
- "SimMean": -0.01,
+ "SimMean": -0.1,
"SimStd": 0.05,
"IsNumeric": true,
"EnablePlot": true,
@@ -40,7 +40,7 @@
"ValueNum": 70,
"MinVal": 0,
"MaxVal": 100,
- "SimMean": -0.025,
+ "SimMean": -0.25,
"SimStd": 0.12,
"IsNumeric": true,
"EnablePlot": true,
@@ -56,7 +56,7 @@
"ValueNum": 70,
"MinVal": 0,
"MaxVal": 100,
- "SimMean": -0.025,
+ "SimMean": -0.25,
"SimStd": 0.12,
"IsNumeric": true,
"EnablePlot": true,
@@ -72,7 +72,7 @@
"ValueNum": 99,
"MinVal": 0,
"MaxVal": 100,
- "SimMean": -0.05,
+ "SimMean": -0.5,
"SimStd": 0.125,
"IsNumeric": true,
"EnablePlot": true,
@@ -88,7 +88,7 @@
"ValueNum": 85,
"MinVal": 0,
"MaxVal": 100,
- "SimMean": -0.01,
+ "SimMean": -0.15,
"SimStd": 0.05,
"IsNumeric": true,
"EnablePlot": true,
@@ -104,7 +104,7 @@
"ValueNum": 70,
"MinVal": 0,
"MaxVal": 100,
- "SimMean": -0.025,
+ "SimMean": -0.35,
"SimStd": 0.12,
"IsNumeric": true,
"EnablePlot": true,
@@ -120,7 +120,7 @@
"ValueNum": 70,
"MinVal": 0,
"MaxVal": 100,
- "SimMean": -0.025,
+ "SimMean": -0.35,
"SimStd": 0.12,
"IsNumeric": true,
"EnablePlot": true,
@@ -136,7 +136,7 @@
"ValueNum": 99,
"MinVal": 0,
"MaxVal": 100,
- "SimMean": -0.05,
+ "SimMean": -0.5,
"SimStd": 0.125,
"IsNumeric": true,
"EnablePlot": true,
@@ -152,7 +152,7 @@
"ValueNum": 85,
"MinVal": 0,
"MaxVal": 100,
- "SimMean": -0.01,
+ "SimMean": -0.15,
"SimStd": 0.05,
"IsNumeric": true,
"EnablePlot": true,
@@ -168,7 +168,7 @@
"ValueNum": 70,
"MinVal": 0,
"MaxVal": 100,
- "SimMean": -0.025,
+ "SimMean": -0.35,
"SimStd": 0.12,
"IsNumeric": true,
"EnablePlot": true,
@@ -184,7 +184,7 @@
"ValueNum": 70,
"MinVal": 0,
"MaxVal": 100,
- "SimMean": -0.025,
+ "SimMean": -0.35,
"SimStd": 0.12,
"IsNumeric": true,
"EnablePlot": true,
@@ -200,7 +200,7 @@
"ValueNum": 99,
"MinVal": 0,
"MaxVal": 100,
- "SimMean": -0.05,
+ "SimMean": -0.5,
"SimStd": 0.125,
"IsNumeric": true,
"EnablePlot": true,
@@ -216,7 +216,7 @@
"ValueNum": 85,
"MinVal": 0,
"MaxVal": 100,
- "SimMean": -0.01,
+ "SimMean": -0.15,
"SimStd": 0.05,
"IsNumeric": true,
"EnablePlot": true,
@@ -232,7 +232,7 @@
"ValueNum": 70,
"MinVal": 0,
"MaxVal": 100,
- "SimMean": -0.025,
+ "SimMean": -0.35,
"SimStd": 0.12,
"IsNumeric": true,
"EnablePlot": true,
@@ -248,7 +248,7 @@
"ValueNum": 70,
"MinVal": 0,
"MaxVal": 100,
- "SimMean": -0.025,
+ "SimMean": -0.35,
"SimStd": 0.12,
"IsNumeric": true,
"EnablePlot": true,
diff --git a/MP.MONO.SIM/conf/Tools.json b/MP.MONO.SIM/conf/Tools.json
index e88c15e..92eeefd 100644
--- a/MP.MONO.SIM/conf/Tools.json
+++ b/MP.MONO.SIM/conf/Tools.json
@@ -9,6 +9,7 @@
"MinVal": 0,
"MaxVal": 100,
"DisplFormat": "N2",
+ "VcFunc": "AVG",
"IsNumeric": true,
"EnablePlot": true,
"ShowBar": true,
@@ -24,6 +25,7 @@
"MinVal": 0,
"MaxVal": 100,
"DisplFormat": "N2",
+ "VcFunc": "AVG",
"IsNumeric": true,
"EnablePlot": true,
"ShowBar": true,
@@ -39,6 +41,7 @@
"MinVal": 0,
"MaxVal": 100,
"DisplFormat": "N2",
+ "VcFunc": "AVG",
"IsNumeric": true,
"EnablePlot": true,
"ShowBar": true,
@@ -54,6 +57,7 @@
"MinVal": 0,
"MaxVal": 100,
"DisplFormat": "N2",
+ "VcFunc": "AVG",
"IsNumeric": true,
"EnablePlot": true,
"ShowBar": true,
@@ -69,6 +73,7 @@
"MinVal": 0,
"MaxVal": 100,
"DisplFormat": "N2",
+ "VcFunc": "AVG",
"IsNumeric": true,
"EnablePlot": true,
"ShowBar": true,
@@ -84,6 +89,7 @@
"MinVal": 0,
"MaxVal": 100,
"DisplFormat": "N2",
+ "VcFunc": "AVG",
"IsNumeric": true,
"EnablePlot": true,
"ShowBar": true,
@@ -99,6 +105,7 @@
"MinVal": 0,
"MaxVal": 100,
"DisplFormat": "N2",
+ "VcFunc": "AVG",
"IsNumeric": true,
"EnablePlot": true,
"ShowBar": true,
@@ -114,6 +121,7 @@
"MinVal": 0,
"MaxVal": 100,
"DisplFormat": "N2",
+ "VcFunc": "AVG",
"IsNumeric": true,
"EnablePlot": true,
"ShowBar": true,
@@ -129,6 +137,7 @@
"MinVal": 0,
"MaxVal": 100,
"DisplFormat": "N2",
+ "VcFunc": "AVG",
"IsNumeric": true,
"EnablePlot": true,
"ShowBar": true,
@@ -144,6 +153,7 @@
"MinVal": 0,
"MaxVal": 100,
"DisplFormat": "N2",
+ "VcFunc": "AVG",
"IsNumeric": true,
"EnablePlot": true,
"ShowBar": true,
@@ -159,6 +169,7 @@
"MinVal": 0,
"MaxVal": 100,
"DisplFormat": "N2",
+ "VcFunc": "AVG",
"IsNumeric": true,
"EnablePlot": true,
"ShowBar": true,
@@ -174,6 +185,7 @@
"MinVal": 0,
"MaxVal": 100,
"DisplFormat": "N2",
+ "VcFunc": "AVG",
"IsNumeric": true,
"EnablePlot": true,
"ShowBar": true,
@@ -189,6 +201,7 @@
"MinVal": 0,
"MaxVal": 100,
"DisplFormat": "N2",
+ "VcFunc": "AVG",
"IsNumeric": true,
"EnablePlot": true,
"ShowBar": true,
@@ -204,6 +217,7 @@
"MinVal": 0,
"MaxVal": 100,
"DisplFormat": "N2",
+ "VcFunc": "AVG",
"IsNumeric": true,
"EnablePlot": true,
"ShowBar": true,
@@ -219,6 +233,7 @@
"MinVal": 0,
"MaxVal": 100,
"DisplFormat": "N2",
+ "VcFunc": "AVG",
"IsNumeric": true,
"EnablePlot": true,
"ShowBar": true,
@@ -234,6 +249,7 @@
"MinVal": 0,
"MaxVal": 100,
"DisplFormat": "N2",
+ "VcFunc": "AVG",
"IsNumeric": true,
"EnablePlot": true,
"ShowBar": true,
diff --git a/MP.MONO.UI/MP.MONO.UI.csproj b/MP.MONO.UI/MP.MONO.UI.csproj
index f1b32c4..b21e105 100644
--- a/MP.MONO.UI/MP.MONO.UI.csproj
+++ b/MP.MONO.UI/MP.MONO.UI.csproj
@@ -5,7 +5,7 @@
enable
enable
AnyCPU;x86;x64
- 1.2.2210.411
+ 1.2.2210.412
diff --git a/MP.MONO.UI/Resources/ChangeLog.html b/MP.MONO.UI/Resources/ChangeLog.html
index 950d47b..20f2999 100644
--- a/MP.MONO.UI/Resources/ChangeLog.html
+++ b/MP.MONO.UI/Resources/ChangeLog.html
@@ -1,6 +1,6 @@
MAPO-MONO
-
Version: 1.2.2210.411
+ Version: 1.2.2210.412
Release Note:
-
diff --git a/MP.MONO.UI/Resources/VersNum.txt b/MP.MONO.UI/Resources/VersNum.txt
index 1699fe2..d7d71d8 100644
--- a/MP.MONO.UI/Resources/VersNum.txt
+++ b/MP.MONO.UI/Resources/VersNum.txt
@@ -1 +1 @@
-1.2.2210.411
+1.2.2210.412
diff --git a/MP.MONO.UI/Resources/manifest.xml b/MP.MONO.UI/Resources/manifest.xml
index a6d3a43..983ca43 100644
--- a/MP.MONO.UI/Resources/manifest.xml
+++ b/MP.MONO.UI/Resources/manifest.xml
@@ -1,6 +1,6 @@
-
- 1.2.2210.411
+ 1.2.2210.412
http://nexus.steamware.net/repository/SWS/MP.MONO.UI/stable/LAST/MP.Mon.zip
http://nexus.steamware.net/repository/SWS/MP.MONO.UI/stable/LAST/ChangeLog.html
false
diff --git a/MP.MONO.DECODER/ToolsManager.cs b/MP.MONO.DECODER/ToolsManager.cs
index 9b360c6..39f6ef6 100644
--- a/MP.MONO.DECODER/ToolsManager.cs
+++ b/MP.MONO.DECODER/ToolsManager.cs
@@ -54,12 +54,12 @@ namespace MP.MONO.DECODER
#region Public Methods
///
/// Funzione chiamata LUA x calcolo degli eventuali parametri con periodi "scaduti"
///
///
- ///
+ ///
///
- public List processData(Dictionary paramsList, List redisParamConf)
+ public List processData(Dictionary paramsList, List redisToolsConf)
{
List answ = new List();
DateTime adesso = DateTime.Now;
@@ -67,7 +67,7 @@ namespace MP.MONO.DECODER
// vado ad "accumulare i dati" a quelli presenti...
foreach (var item in paramsList)
{
- var currParam = redisParamConf.FirstOrDefault(x => x.Title == item.Key);
+ var currParam = redisToolsConf.FirstOrDefault(x => x.Title == item.Key);
// cerco nelle variabili accomulatori...
if (!VarAccumulator.ContainsKey(item.Key))
{
@@ -54,12 +54,12 @@ namespace MP.MONO.DECODER
#region Public Methods
///
- /// Funzione chiamata LUA x calcolo degli eventuali parametri con periodi "scaduti"
+ /// Funzione chiamata LUA x calcolo degli eventuali tools val con periodi "scaduti"
///
///